@@ -21,7 +21,7 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 __author__ = 'Adam Coddington <me@adamcoddington.net>'
-__version__ = (1, 0, 5)
+__version__ = (1, 1, 1)
 
 def run_from_cmdline():
     import logging
@@ -39,7 +39,7 @@ def run_from_cmdline():
     if options.info:
         kwargs['level'] = logging.INFO
     if options.logfile:
-        kwargs['filename'] = logging.logfile
+        kwargs['filename'] = args.logfile
     logging.basicConfig(**kwargs)
     app = TeamspeakNotifier()
     app.main()
